Partition
=========

.. currentmodule:: graspologic.partition

Modularity and Component Modularity
-----------------------------------

.. autofunction:: modularity

.. autofunction:: modularity_components

Leiden and Hierarchical Leiden
------------------------------

.. autofunction:: leiden

.. autoclass:: HierarchicalCluster

.. autofunction:: hierarchical_leiden
